Core functionality for actual scanning behaviour.
Structs
- Scanner
- The class for the scanner IP is data type IpAddr and is the IP address start & end is where the port scan starts and ends batch_size is how many ports at a time should be scanned Timeout is the time RustScan should wait before declaring a port closed. As datatype Duration. greppable is whether or not RustScan should print things, or wait until the end to print only the ip and open ports.